==> sunbird-0.2-source.tar.bz2: mozilla/mailnews/base/src/nsMsgStatusFeedback.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef _nsMsgStatusFeedback_h
#define _nsMsgStatusFeedback_h

#include "nsIWebProgressListener.h"
#include "nsIDOMWindowInternal.h"
#include "nsIObserver.h"
#include "nsITimer.h"
#include "nsCOMPtr.h"
#include "nsIMsgStatusFeedback.h"
#include "nsIProgressEventSink.h"
#include "nsIStringBundle.h"
#include "nsWeakReference.h"
#include "nsIAtom.h"

class nsMsgStatusFeedback : public nsIMsgStatusFeedback,
                            public nsIProgressEventSink,
                            public nsIWebProgressListener,
                            public nsSupportsWeakReference
{
public:
  nsMsgStatusFeedback();
  virtual ~nsMsgStatusFeedback();

  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSTATUSFEEDBACK
  NS_DECL_NSIWEBPROGRESSLISTENER
  NS_DECL_NSIPROGRESSEVENTSINK

protected:
  nsIDOMWindow     *mWindow;
  PRBool           m_meteorsSpinning;
  PRInt32          m_lastPercent;
  PRInt64          m_lastProgressTime;


  void BeginObserving();
  void EndObserving();

  // the JS status feedback implementation object...eventually this object
  // will replace this very C++ class you are looking at.
  nsCOMPtr<nsIMsgStatusFeedback> mStatusFeedback;

  nsCOMPtr<nsIStringBundle> mBundle;
  static nsIAtom* kMsgLoadedAtom;
};

#endif // _nsMsgStatusFeedback_h

==> sunbird-0.3.1.source.tar.bz2: mozilla/mailnews/base/src/nsMsgStatusFeedback.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef _nsMsgStatusFeedback_h
#define _nsMsgStatusFeedback_h

#include "nsIWebProgressListener.h"
#include "nsIObserver.h"
#include "nsITimer.h"
#include "nsCOMPtr.h"
#include "nsIMsgStatusFeedback.h"
#include "nsIProgressEventSink.h"
#include "nsIStringBundle.h"
#include "nsWeakReference.h"
#include "nsIAtom.h"

class nsMsgStatusFeedback : public nsIMsgStatusFeedback,
                            public nsIProgressEventSink,
                            public nsIWebProgressListener,
                            public nsSupportsWeakReference
{
public:
  nsMsgStatusFeedback();
  virtual ~nsMsgStatusFeedback();

  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSTATUSFEEDBACK
  NS_DECL_NSIWEBPROGRESSLISTENER
  NS_DECL_NSIPROGRESSEVENTSINK

protected:
  PRBool           m_meteorsSpinning;
  PRInt32          m_lastPercent;
  PRInt64          m_lastProgressTime;

  void BeginObserving();
  void EndObserving();

  // the JS status feedback implementation object...eventually this object
  // will replace this very C++ class you are looking at.
  nsWeakPtr mJSStatusFeedbackWeak;

  nsCOMPtr<nsIStringBundle> mBundle;
  nsCOMPtr <nsIAtom> m_msgLoadedAtom;
};

#endif // _nsMsgStatusFeedback_h
